@@ -84,18 +84,33 @@ if (Field=="CR"){Fi<-lapply(Fi,function(l) l<-l[nchar(l)>10])}  ## delete not co
 # vector of unique units
 uniqueField<-unique(unlist(Fi))
 
-# normalize reference names
-S<-gsub("\\,",";",uniqueField)
-S<-sub("\\;",",",S);S<-sub("\\;",",",S)
-S<-gsub("\\;.*","",S)
-uniqueField<-unique(S)
-
-Fi=lapply(Fi, function(l){
-  l<-gsub("\\,",";",l)
-  l<-sub("\\;",",",l);l<-sub("\\;",",",l)
-  l<-gsub("\\;.*","",l)
-  return(l)
-})
+if (Field=="CR"){
+  S<-gsub("\\).*",")",uniqueField)
+  S<-gsub(","," ",S)
+  S<-gsub(";"," ",S)
+  uniqueField<-unique(gsub("\\s+", " ", S))
+  Fi<-lapply(Fi, function(l){
+    l<-gsub("\\).*",")",l)
+    l<-gsub(","," ",l)
+    l<-gsub(";"," ",l)
+    l<-gsub("\\s+", " ", l)
+    return(l)
+  })
+} else {
+  # normalize reference names
+  S<-gsub("\\,",";",uniqueField)
+  S<-sub("\\;",",",S)
+  S<-sub("\\;",",",S)
+  S<-gsub("\\;.*","",S)
+  uniqueField<-unique(S)
+  Fi<-lapply(Fi, function(l){
+    l<-gsub("\\,",";",l)
+    l<-sub("\\;",",",l)
+    l<-sub("\\;",",",l)
+    l<-gsub("\\;.*","",l)
+    return(l)
+  })
+  }
 
 if (type=="matrix"){
   # Initialization of WA matrix
