@@ -17,9 +17,10 @@
 #'   \code{DE_TM}\tab   \tab Author's Keywords stemmed through the Porter's stemming algorithm\cr
 #'   \code{TI}\tab   \tab Terms extracted from titles\cr
 #'   \code{AB}\tab   \tab Terms extracted from abstracts}
-#' @param minDegree is an integer. It indicates the number of terms to analize and plot. The default value is 2.
+#' @param minDegree is an integer. It indicates the minimun occurrences of terms to analize and plot. The default value is 2.
 #' @param k.max is an integer. It indicates the maximum numebr of cluster to keep. The default value is 5. The max value is 8.
 #' @param stemming is logical. If TRUE the Porter's Stemming algorithm is applied to all extracted terms. The default is \code{stemming = FALSE}.
+#' @param labelsize is an integer. It indicates the label size in the plot. Default is \code{labelsize=2}
 #' @return It is an object of the class \code{list} containing the following components:
 #'
 #' \tabular{lll}{
@@ -41,7 +42,7 @@
 #' @seealso \code{\link{biblioAnalysis}} to perform a bibliometric analysis.
 #' 
 #' @export
-conceptualStructure <- function(M,field="ID", minDegree=2, k.max=5, stemming=FALSE){
+conceptualStructure <- function(M,field="ID", minDegree=2, k.max=5, stemming=FALSE, labelsize=3){
 
 switch(field,
        ID={
@@ -140,7 +141,7 @@ km.res <- kmeans(scale(df), clust, nstart = 25)
 # Plot of the conceptual map
 cbPalette <- c("#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
 
-b=fviz_cluster(km.res, data = df,labelsize=2)+
+b=fviz_cluster(km.res, data = df,labelsize=labelsize)+
   theme_minimal()+
   scale_color_manual(values = cbPalette[1:clust])+
   scale_fill_manual(values = cbPalette[1:clust]) +
