@@ -99,7 +99,8 @@ scopus2df<-function(D){
   DATA$PY=as.numeric(sub("\\D*(\\d+).*", "\\1", DATA$PY))
 
   #DATA$UT=gsub(":","",DATA$UT,fixed=TRUE)
-  DATA <- mutate_each(DATA, funs(toupper))
+  DATA <- data.frame(lapply(DATA,toupper),stringsAsFactors = FALSE)
+  #DATA <- mutate_each(DATA, funs(toupper))
 
   DATA$DB="SCOPUS"
   return(DATA)
